#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""
Static utility functions shared across casa_envoy
"""
import json
from bs4 import BeautifulSoup
from typing import Dict, Union

from casa_envoy.schema import AbstractTextFile


def get_abs_file(filename: str) -> AbstractTextFile:
    with open(filename, "r") as file:
        content = file.read()
        file.close()
    return AbstractTextFile(filename, content)


def get_xml_content(file: AbstractTextFile) -> BeautifulSoup:
    """
    Get XML content of file in modifiable format

    :param file:
    :return:
    """
    return BeautifulSoup(file.content, "xml")


def get_json_content(file: AbstractTextFile) -> Dict[str, str]:
    return json.loads(file.content)


def get_value_for(content: Union[BeautifulSoup, Dict[str, str]], key: str) -> str:
    if isinstance(content, BeautifulSoup):
        return content.find(key).string
    if isinstance(content, Dict):
        return content[key]
