#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""
Workspaces data delivery module
"""
__version__ = "2.8.7.1"


from datetime import datetime


def convert_datetime_to_mjd(timestamp: datetime) -> float:
    """Convert UTC datetime to MJD
    Sources:
    - https://www.celestialprogramming.com/julian.html for JD
    - https://core2.gsfc.nasa.gov/time/a for MJD
    """
    secs_since_posix_epoch = timestamp.timestamp()
    SECS_IN_DAY = 86400
    SECS_FROM_JD_TO_POSIX_EPOCHS = 2440587.5
    JD_TO_MJD = 2400000.5
    return (secs_since_posix_epoch / SECS_IN_DAY) + SECS_FROM_JD_TO_POSIX_EPOCHS - JD_TO_MJD
