#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""Tests removed: all broke when queue and messaging systems were overhauled.
   This module is kept so as not to break tests; mocks remain
   in case they may be useful Some Fine Day.
"""
# pylint: disable=W1203

import logging
import sys
from typing import Dict
from unittest.mock import patch

import pytest
import wf_monitor.monitor
from messaging.router import Router
from wf_monitor.monitor import WorkflowMonitor

LOG_PATH = "logs/condor.log"

logger = logging.getLogger("test_wf_monitor")
logger.setLevel(logging.INFO)
logger.addHandler(logging.StreamHandler(sys.stdout))


def mock_send_message(message: Dict[str, str], mock_router: Router):
    """
    Mocked version of wf_monitor.monitor.send_event without any AMQP connections being made

    :param message: Workflow event being "sent"
    :param mock_router: Mock router
    """
    logger.info(f"Pretending to send message: {message} from mock router: {mock_router}")


wf_monitor.monitor.send_message = mock_send_message


def mock_monitor_factory(path_to_log: str, timeout: int = 60) -> WorkflowMonitor:
    """
    Factory function that creates a WorkflowMonitor object with external
    dependencies mocked away

    :param path_to_log: Path to log file that will be monitored
    :param timeout: Timeout in seconds

    :return: Mocked WorkflowMonitor
    """
    with patch("wf_monitor.monitor.Router"):
        return WorkflowMonitor(path_to_log, -1, timeout)


@pytest.mark.skip("This is here just to avoid breaking build")
def test_nothing():
    """
    Tests nothing. Here so the wf_monitor works.
    The workflow container can't find wf_monitor if this test isn't here.
    """


#   Still do? This was here when I wrote this comment
#
#   write test for checking is regex parses the following:
#     022 (185.000.000) 2022-05-09 20:56:38 Job disconnected, attempting to reconnect
#     Local schedd and job shadow died, schedd now running again
#     Trying to reconnect to
#     slot1_1@nmpost040.aoc.nrao.edu
#     <10.64.10.140:9618?addrs=10.64.10.140-9618&alias=nmpost040.aoc.nrao.edu&noUDP&sock=startd_31202_8e21>
# ...
