/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Component, OnInit } from '@angular/core';
import { JsonObject } from "@angular/compiler-cli/ngcc/src/packages/entry_point";

import { CapabilityLauncherService } from "../../../../services/capability-launcher.service";
import { Input } from '@angular/core';

@Component({
  selector: 'app-capability-launch-for-observation',
  templateUrl: './capability-launch-for-observation.component.html',
  styleUrls: [ './capability-launch-for-observation.component.scss' ]
})
export class CapabilityLaunchForObservationComponent implements OnInit {

  public sdmId: string;
  @Input() capabilityName: string;

  constructor(public capabilityLauncher: CapabilityLauncherService ) {
  }

  ngOnInit(): void {
  }

  setSdmId(sdmId: string): void {
    this.sdmId = sdmId.trim();
  }

  launchSelectedCapabilityOnSelectedSdm(): void {
    this.launchCapability(this.capabilityName, {
      "sdmId" : this.sdmId
    })
  }

  launchCapability(capabilityName: string, parameters: JsonObject): void {
    const createRequestObserver = {
      next: (requestResponse: any) => {},
      error: (error) => {
        console.log(error);
      },
    };

    this.capabilityLauncher.launchCapability(
      capabilityName, parameters
    ).subscribe(createRequestObserver)
  }
}
