import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ProcessingSettings } from "../model/processing-settings";
import { JsonObject } from "@angular/compiler-cli/ngcc/src/packages/entry_point";

@Injectable({
  providedIn: 'root'
})
export class SettingsService {

  constructor(private httpClient: HttpClient) { }

  /**
   * Get the current processing settings from the database
   * @return Observable<ProcessingSettings> Result of the REST call
   */
  getProcessingSettings(): Observable<ProcessingSettings> {
    const url = `settings`
    return this.httpClient.get<ProcessingSettings>(url)
  }

  /**
   * Update the processing setting for current needs
   * @param parameters settings to update
   * example parameters: {
   *         "default_capability": "std_calibration_and_imaging",
   *         "auto_submit_status": "PAUSE"
   *     }
   */
  updateProcessingSettings(parameters: JsonObject): Observable<ProcessingSettings> {
    const url = `settings/update`
    return this.httpClient.put<ProcessingSettings>(url, JSON.stringify(parameters))
  }


}
