How to Upgrade the Local Development Docker Database
---------------------------------

1. ssh to the system with the database you want to use as the base of the database
~~~
ssh postgres@<server>
~~~
2. run pg_dump for the archive database as follows:
~~~
pg_dump -s -O --exclude-table=capability_* --exclude-table=notification_* --exclude-table=workflow_* --exclude-table=capabilities --exclude-table=workflows --exclude-table=processing_* --exclude-table=ws_* --exclude-table=casa_matrix_* --exclude-table=qa_* archive > archive-schema.sql 
~~~
-s is schema only
-O is without ownership
--exclude-table allows skipping specific table patterns
~~~
pg_dumpall -r archive > roles.sql
~~~
-r is roles only

3. Remove the 'archive' role from roles.sql. Docker creates this on container startup
4. Concatenate roles.sql and archive-schema.sql and gzip
~~~
cat roles.sql archive-schema.sql > newarchive.sql
gzip newarchive.sql 
~~~
This allows us to set up a clean copy of the archive database. However, we will also need to provide some 
basic data before we can import our test projects.
~~~
pg_dump -a --table=calibration_status_values --table=collection_name_values --table=science_product_types --table=science_product_group_types --table=acknowledgements --table=external_product_systems --table=polarizations --table=receivers archive > basics.sql
gzip basics.sql
~~~
-a is data only, no schema
--table allows command actions only for the specified table
5. Exit the server
6. On your local machine, in the relevant branch, navigate to the ci/psql/ directory.
7. Copy down the sql archive and basics files and replace the old archive_data.sql.gz file
~~~
scp postgres@<server>:basics.sql.gz .
scp postgres@<server>:newarchive.sql.gz .
mv newarchive.sql.gz archive_data.sql.gz
~~~

8. Next we'll need to update our core samples of the local test project data.
9. Make sure you have a runable version of core_sampler available. Either pip install it locally, use poetry run, or build a pex.
10. Run core_sampler aimed at the dev system. Running with poetry is shown below
~~~
CAPO_PROFILE=dsoc-dev poetry run core_sampler -p 2017.1.00870.S --exclude-table=rh_locators --exclude-table=science_product_comments > <relevant path>/ci/psql/project_2017.1.00870.S.sql
gzip project_2017.1.00870.S.sql
~~~
We are excluding rh_locators and the data comments from the returned file for simplicity. 

11. Build your workspaces docker containers. Once this is complete you should have a usable, current database.

