"""
File containing definitions for the global default settings routes of the Workspaces REST API
"""
import http

from pyramid.request import Request
from pyramid.response import Response
from pyramid.view import view_config
from pyramid.httpexceptions import HTTPBadRequest

from capability.views.helpers import parse_body


@view_config(route_name="get_current_settings", renderer="json")
def get_current_settings(request: Request) -> Response:
    """
    Return the current settings
    /archive_service/settings

    :param request: GET request
    :return:
    """

    settings = request.archive_service.capability_manager.get_settings()

    if settings:
        return Response(status=http.HTTPStatus.OK, json_body=settings.__json__())
    else:
        return HTTPBadRequest(detail="unable to retrieve settings.")


@view_config(route_name="update_settings", renderer="json")
def update_settings(request: Request) -> Response:
    """
    Update the specified setting(s) as requested

    :param request: PUT request
    :return:
    """
    body = parse_body(request)
    print(body)

    if len(body) < 1:
        # if there is not at least 1 key to update, fail
        return HTTPBadRequest(detail="No settings to update specified.")

    updates = request.archive_service.capability_manager.update_settings(body)

    # verify updates here

    if updates:
        return Response(status=http.HTTPStatus.OK, json_body=updates.__json__())
    else:
        return HTTPBadRequest(detail="settings failed to update.")
