# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""alma restores

Revision ID: 175c5c2accf8
Revises: 528a9fb95936
Create Date: 2024-07-18 09:58:07.092540

"""
from pathlib import Path

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "175c5c2accf8"
down_revision = "528a9fb95936"
branch_labels = None
depends_on = None

workflow = "restore_cms"
old_suffix = "_condor_2.8.4.txt"
new_suffix = "_condor_2.8.5.txt"


def set_content(filename: str) -> bytes:
    return (Path.cwd() / "versions" / "templates" / workflow / filename).read_text().encode()


def upgrade():
    conn = op.get_bind()

    # Update the workflow to allow remote processing
    conn.execute(
        f"""
        UPDATE workflows
        SET remote_capable = true
        WHERE workflow_name = E'{workflow}'
        """
    )

    # Update the restore_cms condor templates to handle processing in CV
    for task in ["fetch", "envoy", "deliver"]:
        conn.execute(
            f"""
            UPDATE workflow_templates
            SET content=%s
            WHERE filename=E'{workflow}_{task}.condor' AND workflow_name=E'{workflow}'
            """,
            set_content(task + new_suffix),
        )

    # Update the remaining sh templates to handle processing in CV
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content=%s
        WHERE filename=E'{workflow}_envoy.sh' AND workflow_name=E'{workflow}'
        """,
        set_content('envoy_sh_2.8.5.txt'),
    )


def downgrade():
    conn = op.get_bind()

    conn.execute(
        f"""
        UPDATE workflows
        SET remote_capable = false
        WHERE workflow_name = E'{workflow}'
        """
    )

    for task in ["fetch", "envoy", "deliver"]:
        conn.execute(
            f"""
            UPDATE workflow_templates
            SET content=%s
            WHERE filename=E'{workflow}_{task}.condor' AND workflow_name=E'{workflow}'
            """,
            set_content(task + old_suffix),
        )

    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content=%s
        WHERE filename=E'{workflow}_envoy.sh' AND workflow_name=E'{workflow}'
        """,
        set_content('envoy_sh_2.8.4.txt'),
    )
