# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""annihilation counters

Revision ID: 4d9fbb433897
Revises: 65701206914e
Create Date: 2024-08-28 09:43:25.983465

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "4d9fbb433897"
down_revision = "65701206914e"
branch_labels = None
depends_on = None


def upgrade():
    # Add new columns to track annihilations
    op.add_column(
        "workflow_requests",
        sa.Column(
            "num_to_clean",
            sa.Integer,
            server_default="0",
            nullable=False,
            comment="Number of areas to annihilate to be considered cleaned",
        ),
    )

    op.add_column(
        "workflow_requests",
        sa.Column(
            "num_cleaned",
            sa.Integer,
            server_default="0",
            nullable=False,
            comment="Number of areas annihilated",
        ),
    )

    # Use previous cleaned values to set defaults for completed workflows so they'll get cleaned
    op.execute(
        """
        UPDATE workflow_requests
        SET num_to_clean = 1
        """
    )

    op.execute(
        """
        UPDATE workflow_requests
        SET num_cleaned = 1 WHERE cleaned = true
        """
    )

    op.execute(
        """
        UPDATE workflow_requests
        SET num_cleaned = 0 WHERE cleaned = false
        """
    )

    # Change cleaned column to be computed from the new columns (cannot alter column to become generated, must drop+add)
    op.execute(
        """
        ALTER TABLE workflow_requests
        DROP COLUMN IF EXISTS cleaned
        """
    )

    op.execute(
        """
        ALTER TABLE workflow_requests
        ADD COLUMN cleaned boolean GENERATED ALWAYS AS (num_to_clean <= num_cleaned) STORED
        """
    )


def downgrade():
    op.execute(
        """
        ALTER TABLE workflow_requests
        DROP COLUMN IF EXISTS cleaned
        """
    )

    op.execute(
        """
        ALTER TABLE workflow_requests
        ADD COLUMN cleaned boolean DEFAULT false
        """
    )

    op.execute(
        """
        UPDATE workflow_requests
        SET cleaned = true WHERE num_to_clean = num_cleaned
        """
    )

    op.execute(
        """
        ALTER TABLE workflow_requests
        DROP COLUMN IF EXISTS num_to_clean
        """
    )

    op.execute(
        """
        ALTER TABLE workflow_requests
        DROP COLUMN IF EXISTS num_cleaned
        """
    )
