# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""ingest products workflow

Revision ID: 7ba77453966a
Revises: 58690eec160b
Create Date: 2024-09-23 14:28:25.260873

"""
from pathlib import Path

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "7ba77453966a"
down_revision = "58690eec160b"
branch_labels = None
depends_on = None


new_wf_name = "ingest_products"


def set_content(wf_name: str, filename: str) -> str:
    return (Path.cwd() / "versions" / "templates" / wf_name / filename).read_text()


def upgrade():
    """
    Inserts a new 'ingest_products' workflow to replace both the `ingest_cal` and `ingest_image` workflows.
    """
    conn = op.get_bind()

    # Insert workflow
    op.execute(
        f"""
        INSERT INTO workflows (workflow_name, requires_lustre) VALUES (E'{new_wf_name}', true)
        """
    )

    # Insert new templates
    conn.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES (%s, %s, %s)
        """,
        new_wf_name + ".condor",
        set_content(new_wf_name, f"{new_wf_name}_condor_2.8.6.txt"),
        new_wf_name,
    )

    conn.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES (%s, %s, %s)
        """,
        new_wf_name + ".sh",
        set_content(new_wf_name, f"{new_wf_name}_sh_2.8.6.txt"),
        new_wf_name,
    )

    conn.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES (%s, %s, %s)
        """,
        "aux_image_metadata.json",
        set_content(new_wf_name, f"{new_wf_name}_aux_image_metadata_2.8.6.txt"),
        new_wf_name,
    )


def downgrade():
    op.execute(
        f"""
        DELETE FROM workflow_templates WHERE workflow_name = E'{new_wf_name}'
        """
    )

    op.execute(
        f"""
        DELETE FROM workflows WHERE workflow_name = E'{new_wf_name}'
        """
    )
