# Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
#
"""One newline at the end of all templates

Revision ID: 8d632a11a047
Revises: 30a155c9bb19
Create Date: 2024-10-21 12:19:27.306576

"""
from pathlib import Path

from alembic import op

# revision identifiers, used by Alembic.
revision = "8d632a11a047"
down_revision = "30a155c9bb19"
branch_labels = None
depends_on = None


def get_template_content(dir_name: str, file_name: str) -> str:
    return (Path.cwd() / "versions" / "templates" / dir_name / file_name).read_text()


# Workflow templates that need to be updated
# Format: [workflow name, filename, old template content, new template content]
workflow_templates = [
    # carta-debug dir
    [
        "carta-debug",
        "carta.condor",
        get_template_content("carta-debug", "condor_pre_2.8.6.txt"),
        get_template_content("carta-debug", "condor_2.8.6.txt"),
    ],
    # carta dir
    [
        "carta",
        "carta.condor",
        get_template_content("carta", "condor_pre_2.8.6.txt"),
        get_template_content("carta", "condor_2.8.6.txt"),
    ],
    # curator dir
    [
        "curator",
        "curator.condor",
        get_template_content("curator", "condor_pre_2.8.6.txt"),
        get_template_content("curator", "condor_2.8.6.txt"),
    ],
    [
        "curator",
        "curator.sh",
        get_template_content("curator", "sh_pre_2.8.6.txt"),
        get_template_content("curator", "sh_2.8.6.txt"),
    ],
    [
        "curator",
        "metadata.json",
        get_template_content("curator", "metadata_2.8.3.txt"),
        get_template_content("curator", "metadata_2.8.6.txt"),
    ],
    # download dir
    [
        "download",
        "download.condor",
        get_template_content("downloads", "condor_pre_2.8.6.txt"),
        get_template_content("downloads", "condor_2.8.6.txt"),
    ],
    # ingest_cal dir
    [
        "ingest_cal",
        "ingest_cal.condor",
        get_template_content("ingest_cal", "condor_pre_2.8.6.txt"),
        get_template_content("ingest_cal", "condor_2.8.6.txt"),
    ],
    [
        "ingest_cal",
        "ingest_cal.sh",
        get_template_content("ingest_cal", "sh_pre_2.8.6.txt"),
        get_template_content("ingest_cal", "sh_2.8.6.txt"),
    ],
    # ingest_image dir
    [
        "ingest_image",
        "ingest_image.condor",
        get_template_content("ingest_image", "condor_pre_2.8.6.txt"),
        get_template_content("ingest_image", "condor_2.8.6.txt"),
    ],
    [
        "ingest_image",
        "ingest_image.sh",
        get_template_content("ingest_image", "sh_pre_2.8.6.txt"),
        get_template_content("ingest_image", "sh_2.8.6.txt"),
    ],
    # ingest_obs dir
    [
        "ingest_obs",
        "ingest_obs.condor",
        get_template_content("ingest_obs", "condor_pre_2.8.6.txt"),
        get_template_content("ingest_obs", "condor_2.8.6.txt"),
    ],
    [
        "ingest_obs",
        "ingest_obs.sh",
        get_template_content("ingest_obs", "sh_pre_2.8.6.txt"),
        get_template_content("ingest_obs", "sh_2.8.6.txt"),
    ],
    [
        "ingest_obs",
        "metadata.json",
        get_template_content("ingest_obs", "metadata_pre_2.8.6.txt"),
        get_template_content("ingest_obs", "metadata_2.8.6.txt"),
    ],
    # ingest_seci dir
    [
        "ingest_seci",
        "ingest_seci.condor",
        get_template_content("ingest_seci", "condor_pre_2.8.6.txt"),
        get_template_content("ingest_seci", "condor_2.8.6.txt"),
    ],
    [
        "ingest_seci",
        "ingest_seci.sh",
        get_template_content("ingest_seci", "sh_pre_2.8.6.txt"),
        get_template_content("ingest_seci", "sh_2.8.6.txt"),
    ],
    [
        "ingest_seci",
        "metadata.json",
        get_template_content("ingest_seci", "aux_image_metadata_pre_2.8.6.txt"),
        get_template_content("ingest_seci", "aux_image_metadata_2.8.6.txt"),
    ],
    # mk_four_import dir
    [
        "mk_four_import",
        "mk_four_import.condor",
        get_template_content("mk_four_import", "condor_pre_2.8.6.txt"),
        get_template_content("mk_four_import", "condor_2.8.6.txt"),
    ],
    [
        "mk_four_import",
        "mk_four_import.sh",
        get_template_content("mk_four_import", "sh_pre_2.8.6.txt"),
        get_template_content("mk_four_import", "sh_2.8.6.txt"),
    ],
    # pims_split dir
    [
        "pims_split",
        "restore.condor",
        get_template_content("pims_split", "restore_condor_pre_2.8.6.txt"),
        get_template_content("pims_split", "restore_condor_2.8.6.txt"),
    ],
    [
        "pims_split",
        "write_finished_file.condor",
        get_template_content("pims_split", "write_finished_file_condor_pre_2.8.6.txt"),
        get_template_content("pims_split", "write_finished_file_condor_2.8.6.txt"),
    ],
    [
        "pims_split",
        "metadata.json",
        get_template_content("pims_split", "metadata_pre_2.8.6.txt"),
        get_template_content("pims_split", "metadata_2.8.6.txt"),
    ],
    # qa_fail dir
    [
        "qa_fail",
        "qa_fail.condor",
        get_template_content("qa_fail", "condor_pre_2.8.6.txt"),
        get_template_content("qa_fail", "condor_2.8.6.txt"),
    ],
    [
        "qa_fail",
        "qa_fail.sh",
        get_template_content("qa_fail", "sh_pre_2.8.6.txt"),
        get_template_content("qa_fail", "sh_2.8.6.txt"),
    ],
    # restore_cms dir
    [
        "restore_cms",
        "restore_cms.dag",
        get_template_content("restore_cms", "dag_pre_2.8.6.txt"),
        get_template_content("restore_cms", "dag_2.8.6.txt"),
    ],
    [
        "restore_cms",
        "metadata.json",
        get_template_content("restore_cms", "metadata_2.8.5.1.txt"),
        get_template_content("restore_cms", "metadata_2.8.6.txt"),
    ],
    # std_calibration dir
    [
        "std_calibration",
        "std_calibration_convey.condor",
        get_template_content("std_calibration", "convey_condor_pre_2.8.6.txt"),
        get_template_content("std_calibration", "convey_condor_2.8.6.txt"),
    ],
    [
        "std_calibration",
        "std_calibration_envoy.sh",
        get_template_content("std_calibration", "envoy_sh_pre_2.8.6.txt"),
        get_template_content("std_calibration", "envoy_sh_2.8.6.txt"),
    ],
    [
        "std_calibration",
        "std_calibration_envoy.condor",
        get_template_content("std_calibration", "envoy_condor_pre_2.8.6.txt"),
        get_template_content("std_calibration", "envoy_condor_2.8.6.txt"),
    ],
    [
        "std_calibration",
        "std_calibration_fetch.condor",
        get_template_content("std_calibration", "fetch_condor_pre_2.8.6.txt"),
        get_template_content("std_calibration", "fetch_condor_2.8.6.txt"),
    ],
    [
        "std_calibration",
        "metadata.json",
        get_template_content("std_calibration", "metadata_pre_2.8.6.txt"),
        get_template_content("std_calibration", "metadata_2.8.6.txt"),
    ],
    # std_cms_imaging dir
    [
        "std_cms_imaging",
        "std_cms_imaging_envoy.sh",
        get_template_content("std_cms_imaging", "envoy_2.8.1.txt"),
        get_template_content("std_cms_imaging", "envoy_sh_2.8.6.txt"),
    ],
    [
        "std_cms_imaging",
        "metadata.json",
        get_template_content("std_cms_imaging", "metadata_pre_2.8.6.txt"),
        get_template_content("std_cms_imaging", "metadata_2.8.6.txt"),
    ],
    # std_restore_imaging dir
    [
        "std_restore_imaging",
        "std_restore_imaging_envoy.condor",
        get_template_content("std_restore_imaging", "envoy_condor_pre_2.8.6.txt"),
        get_template_content("std_restore_imaging", "envoy_condor_2.8.6.txt"),
    ],
    [
        "std_restore_imaging",
        "std_restore_imaging_envoy.sh",
        get_template_content("std_restore_imaging", "envoy_sh_pre_2.8.6.txt"),
        get_template_content("std_restore_imaging", "envoy_sh_2.8.6.txt"),
    ],
    [
        "std_restore_imaging",
        "metadata.json",
        get_template_content("std_restore_imaging", "metadata_pre_2.8.6.txt"),
        get_template_content("std_restore_imaging", "metadata_2.8.6.txt"),
    ],
    # vlass_calibration dir
    [
        "vlass_calibration",
        "vlass_calibration_envoy.condor",
        get_template_content("vlass_calibration", "envoy_condor_pre_2.8.6.txt"),
        get_template_content("vlass_calibration", "envoy_condor_2.8.6.txt"),
    ],
    # vlass_coarse dir
    [
        "vlass_coarse",
        "vlass_coarse_post.condor",
        get_template_content("vlass_coarse", "post_condor_pre_2.8.6.txt"),
        get_template_content("vlass_coarse", "post_condor_2.8.6.txt"),
    ],
    # vlass_seci dir
    [
        "vlass_seci",
        "vlass_seci_fetch.condor",
        get_template_content("vlass_seci", "fetch_condor_pre_2.8.6.txt"),
        get_template_content("vlass_seci", "fetch_condor_2.8.6.txt"),
    ],
    [
        "vlass_seci",
        "vlass_seci_post.condor",
        get_template_content("vlass_seci", "post_condor_pre_2.8.6.txt"),
        get_template_content("vlass_seci", "post_condor_2.8.6.txt"),
    ],
    [
        "vlass_seci",
        "vlass_seci_post.sh",
        get_template_content("vlass_seci", "post_2.8.1.txt"),
        get_template_content("vlass_seci", "post_sh_2.8.6.txt"),
    ],
]

carta_sh_workflow_templates = [
    [
        "carta-debug",
        "carta.sh",
        bytes(get_template_content("carta-debug", "sh_pre_2.8.6.txt"), "utf-8"),
        bytes(get_template_content("carta-debug", "sh_2.8.6.txt"), "utf-8"),
    ],
    [
        "carta",
        "carta.sh",
        bytes(get_template_content("carta", "sh_pre_2.8.6.txt"), "utf-8"),
        bytes(get_template_content("carta", "sh_2.8.6.txt"), "utf-8"),
    ],
]

# Notification templates that need to be updated
# Format: [name, old template content, new template content]
notification_templates = [
    # email dir
    [
        "carta_expired",
        get_template_content("emails", "carta_expired_pre_2.8.6.txt"),
        get_template_content("emails", "carta_expired_2.8.6.txt"),
    ],
    [
        "qa_revisit",
        get_template_content("emails", "qa_revisit_pre_2.8.6.txt"),
        get_template_content("emails", "qa_revisit_2.8.6.txt"),
    ],
    [
        "stage_2_review",
        get_template_content("emails", "stage_2_review_pre_2.8.6.txt"),
        get_template_content("emails", "stage_2_review_2.8.6.txt"),
    ],
    [
        "workflow_failed",
        get_template_content("emails", "workflow_failed_pre_2.8.6.txt"),
        get_template_content("emails", "workflow_failed_2.8.6.txt"),
    ],
]


def upgrade():
    conn = op.get_bind()

    for template_list in workflow_templates:
        conn.execute(
            """
            UPDATE workflow_templates
            SET content=E%s
            WHERE filename=%s
            AND workflow_name=%s
            """,
            template_list[3],
            template_list[1],
            template_list[0],
        )

    for template_list in carta_sh_workflow_templates:
        conn.execute(
            f"""
            UPDATE workflow_templates
            SET content=%s WHERE filename=%s
            AND workflow_name=%s
            """,
            template_list[3],
            template_list[1],
            template_list[0],
        )

    for template_list in notification_templates:
        conn.execute(
            """
            UPDATE notification_templates
            SET template=%s WHERE name=%s
            """,
            template_list[2],
            template_list[0],
        )


def downgrade():
    conn = op.get_bind()

    for template_list in workflow_templates:
        conn.execute(
            """
            UPDATE workflow_templates
            SET content=E%s
            WHERE filename=%s
            AND workflow_name=%s
            """,
            template_list[2],
            template_list[1],
            template_list[0],
        )

    for template_list in carta_sh_workflow_templates:
        conn.execute(
            f"""
        UPDATE workflow_templates
        SET content=%s WHERE filename=%s
        AND workflow_name=%s
        """,
            template_list[2],
            template_list[1],
            template_list[0],
        )

    for template_list in notification_templates:
        conn.execute(
            """
            UPDATE notification_templates
            SET template=%s WHERE name=%s
            """,
            template_list[1],
            template_list[0],
        )
