#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
from datetime import datetime

from immutable_views import DictView

from workspaces.system.views import ViewWorkflowCapoParameters
from workspaces.workflow.schema import Workflow, WorkflowRequest

"""
tests for views.ViewWorkflowCapoParameters
"""
expected_list = DictView(
    {
        "general": [
            "edu.nrao.workspaces.WorkflowSettings.serviceUrl",
            "edu.nrao.workspaces.NotificationSettings.serviceUrl",
            "edu.nrao.workspaces.UISettings.serviceUrl",
        ],
        "delivery_requirements": [
            "edu.nrao.workspaces.DeliverySettings.downloadDirectory",
            "edu.nrao.workspaces.DeliverySettings.downloadUrl",
        ],
        "fetcher_requirements": [
            "edu.nrao.workspaces.ProductFetcherSettings.locatorServiceUrlPrefix",
            "edu.nrao.workspaces.ProductFetcherSettings.defaultThreadsPerHost",
            "edu.nrao.workspaces.ProductFetcherSettings.executionSite",
            "edu.nrao.workspaces.ProductFetcherSettings.metadataServiceUrlPrefix",
            "almaMetadataDatabase.jdbcUsername",
            "almaMetadataDatabase.jdbcPassword",
            "almaMetadataDatabase.jdbcUrl",
        ],
        "casa_requirements": [
            "edu.nrao.workspaces.ProcessingSettings.useCasa",
            "edu.nrao.workspaces.ProcessingSettings.CasaVersion.vlass",
            "edu.nrao.archive.workflow.config.CasaVersions.homeForReprocessing",
        ],
        "processing_requirements": [
            "edu.nrao.workspaces.ProcessingSettings.rootDirectory",
            "edu.nrao.workspaces.ProcessingSettings.scriptLocation",
        ],
    }
)

remote_request = WorkflowRequest(
    workflow_request_id=-3,
    workflow=Workflow(workflow_name="vlass_seci", uses_casa=True),
    workflow_name="vlass_seci",
    argument={},
    state="Created",
    created_at=datetime(2021, 1, 1),
    updated_at=datetime(2021, 1, 1),
)
remote_view = ViewWorkflowCapoParameters(remote_request, False)

remote_cv_request = WorkflowRequest(
    workflow_request_id=-4,
    workflow=Workflow(workflow_name="restore_cms", uses_casa=True),
    workflow_name="restore_cms",
    argument={"remote-cv": True},
    state="Created",
    created_at=datetime(2021, 1, 1),
    updated_at=datetime(2021, 1, 1),
)
remote_cv_view = ViewWorkflowCapoParameters(remote_cv_request, True)


class TestViewWorkflowCapoParameters:
    def test_remote_general_parameters(self):
        general_params = remote_view.general_parameters()
        assert set(general_params) == set(expected_list["general"])

    def test_remote_casa_parameters(self):
        casa_params = remote_view.casa_parameters()
        assert set(casa_params) == set(expected_list["casa_requirements"])

    def test_remote_construct_view(self):
        constructed_view = remote_view.construct_view()
        assert set(constructed_view) == set(expected_list["general"] + expected_list["casa_requirements"])

    def test_remote_cv_general_parameters(self):
        general_params = remote_cv_view.general_parameters()
        assert set(general_params) == set(expected_list["general"])

    def test_remote_cv_delivery_parameters(self):
        delivery_params = remote_cv_view.delivery_parameters()
        assert set(delivery_params) == set(expected_list["delivery_requirements"])

    def test_remote_cv_fetcher_parameters(self):
        fetcher_params = remote_cv_view.fetcher_parameters()
        assert set(fetcher_params) == set(expected_list["fetcher_requirements"])

    def test_remote_cv_casa_parameters(self):
        casa_params = remote_cv_view.casa_parameters()
        assert set(casa_params) == set(expected_list["casa_requirements"])

    def test_remote_cv_processing_parameters(self):
        processing_params = remote_cv_view.processing_parameters()
        assert set(processing_params) == set(expected_list["processing_requirements"])

    def test_remote_cv_construct_view(self):
        constructed_view = remote_cv_view.construct_view()
        assert set(constructed_view) == set(
            expected_list["general"]
            + expected_list["delivery_requirements"]
            + expected_list["fetcher_requirements"]
            + expected_list["casa_requirements"]
            + expected_list["processing_requirements"]
        )
