#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
from abc import ABC, abstractmethod


class EstimationServiceIF(ABC):
    """
    Service that estimates how long a capability will take to complete
    """

    pass


class MetricsServiceIF(ABC):
    """
    Service that records metrics
    """

    pass


class ArchiveServiceIF(ABC):
    """
    Abstracts services that are needed from the archive system.
    """

    @abstractmethod
    def on_ingestion_complete(self, **message: dict):
        """
        Catch ingestion-complete events

        :param message: the failure message
        :return:
        """

        raise NotImplementedError


class CasaMatrixServiceIF(ABC):
    """
    Service that is needed for the CASA Version Matrix.
    """

    @abstractmethod
    def get_version(
        self, version: str | None = None, capability: str | None = None, telescope: str | None = None
    ) -> dict[str, str]:
        raise NotImplementedError

    @abstractmethod
    def get_versions(
        self, version: str | None = None, capability: str | None = None, telescope: str | None = None
    ) -> list[dict[str, str]]:
        raise NotImplementedError

    @abstractmethod
    def get_recipe(
        self, capability: str, version: str | None = None, telescope: str | None = None, version_path: str | None = None
    ) -> dict[str, str, str]:
        raise NotImplementedError

    @abstractmethod
    def add_version(self, version: str, capabilities: list[str] | None, is_cluster_compatible: bool = True) -> bool:
        raise NotImplementedError

    @abstractmethod
    def update_version(self, version: str, capabilities: list[str] | None, is_cluster_compatible: bool = True) -> bool:
        raise NotImplementedError

    @abstractmethod
    def delete_version(self, version: str) -> bool:
        raise NotImplementedError

    @abstractmethod
    def make_links(self, dry_run: bool = False) -> dict[str, list[str]]:
        raise NotImplementedError
